@@ -1,3 +1,4 @@
+from copy import copy
 from typing import Any, Union, cast
 
 from graphql import (
@@ -20,7 +21,6 @@ from strawberry.utils.inspect import get_func_args
 
 from ..printer import print_schema
 from ..schema import Schema as BaseSchema
-from .schema_directives import Key
 
 
 class Schema(BaseSchema):
@@ -63,20 +63,17 @@ class Schema(BaseSchema):
 
         if entity_type:
             self._schema.type_map[entity_type.name] = entity_type
-
             fields["_entities"] = self._get_entities_field(entity_type)
 
+        # Copy the query type, update it to use the modified fields
         query_type = cast(GraphQLObjectType, self._schema.query_type)
         fields.update(query_type.fields)
+        query_type = copy(query_type)
+        query_type._fields = fields
 
-        self._schema.query_type = GraphQLObjectType(
-            name=query_type.name,
-            description=query_type.description,
-            fields=fields,
-        )
-
+        self._schema.query_type = query_type
         self._schema.type_map["_Service"] = self._service_type
-        self._schema.type_map[self._schema.query_type.name] = self._schema.query_type
+        self._schema.type_map[query_type.name] = query_type
 
     def _get_entities_field(self, entity_type: GraphQLUnionType) -> GraphQLField:
         return GraphQLField(
@@ -128,7 +125,9 @@ def _get_entity_type(type_map: TypeMap):
 
 
 def _is_key(directive: Any) -> bool:
-    return directive.wrap is Key.wrap  # type: ignore
+    from .schema_directives import Key
+
+    return isinstance(directive, Key)
 
 
 def _has_federation_keys(
